@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -48,9 +48,10 @@ public abstract class AbstractExportResultConverter implements ExportResultConve
 
     private static final org.slf4j.Logger LOG = org.slf4j.LoggerFactory.getLogger(AbstractExportResultConverter.class);
 
+    protected static final String CRLF = "\r\n";
+
     protected static final char TEXT_QUALIFIER = '"';
     protected static final char CELL_DELIMITER = ';';
-    protected static final char CARRIAGE_RETURN = '\r';
 
     protected final Collection<Feedback> feedbacks;
 
@@ -170,7 +171,8 @@ public abstract class AbstractExportResultConverter implements ExportResultConve
                 bob.append(this.delimiter);
             }
         }
-        bob.setCharAt(bob.length() - 1, CARRIAGE_RETURN);
+        bob.deleteCharAt(bob.length() - 1);
+        bob.append(CRLF);
         return bob.toString();
     }
 
@@ -218,33 +220,28 @@ public abstract class AbstractExportResultConverter implements ExportResultConve
             return value;
         }
 
-        StringBuilder builder = null;
+        StringBuilder builder = new StringBuilder(length);
 
         char firstChar = value.charAt(0);
         if (needsSanitizing(firstChar)) {
-            builder = new StringBuilder(length);
             builder.append('\'').append(firstChar);
+        } else {
+            builder.append(firstChar);
         }
 
         for (int i = 1; i < length; i++) {
             char c = value.charAt(i);
-            if (null == builder) {
-                if (c == '|') {
-                    builder = new StringBuilder(length);
-                    if (i > 0) {
-                        builder.append(value, 0, i);
-                    }
-                    builder.append("\\").append(c);
-                }
-            } else {
-                if (c == '|') {
-                    builder.append("\\").append(c);
-                } else {
-                    builder.append(c);
-                }
+            if (c == '|') {
+                builder.append("\\").append(c);
+                continue;
             }
+            if (Character.isISOControl(c) && !Character.isWhitespace(c)) {
+                continue;
+            }
+            builder.append(c);
         }
-        return null == builder ? value : builder.toString();
+
+        return builder.toString();
     }
 
     /**
@@ -256,13 +253,9 @@ public abstract class AbstractExportResultConverter implements ExportResultConve
     private boolean needsSanitizing(char c) {
         switch (c) {
             case '=':
-                return true;
             case '+':
-                return true;
             case '-':
-                return true;
             case '@':
-                return true;
             case '|':
                 return true;
             default:
